@@ -27,7 +27,7 @@ open Common
 let use_colors = ref false
 let output_file = ref None
 let input_source = ref Ben.Types.NoSource
-let baseurl = ref "https://people.canonical.com/~ubuntu-archive/transitions/"
+let baseurl = ref "https://transitions.ubuntu.com/"
 
 type output_format = Text | Xhtml | Levels | Json
 
@@ -320,8 +320,8 @@ let generated_on_text () =
     txt " ";
     txt Version.version;
     txt (Printf.sprintf " on %s" (Core.get_rfc2822_date ()));
-    txt "; bzr branch ";
-    a_link "https://code.launchpad.net/+branch/ubuntu-transition-tracker" "lp:ubuntu-transition-tracker"
+    txt "; git repository ";
+    a_link "https://code.launchpad.net/ubuntu-transition-tracker/+git" "lp:ubuntu-transition-tracker"
   ]
 
 let overrall_state l =
